@@ -29,7 +29,7 @@ class Ant():
         if posi == None:
             self.position = [0,0]       #蚂蚁初始位置[y,x] = [0,0],考虑到列表索引的特殊性，先定y，后定x
         if dest == None:
-            self.destination = [len(map_data)-1,len(map_data)]
+            self.destination = [len(map_data)-1,len(map_data)-1]
         #Step 1:不断找下一节点，直到走到终点或者力竭 
         for i in range(self.max_step):
             r = self.select_next_node(map_data,pher_data)
